@@ -1,6 +1,10 @@
 describe.factor.mix<-function(){
-category <- "censored"
+category <- "mixed"
 description  <- "Mixed Data Factor Analysis"
+
+authors <- c("Ben Goodrich", "Ying Lu")
+year <- 2007
+
 package <-list(	name 	="MCMCpack",
 		version	="0.6"
 		)
@@ -10,8 +14,8 @@ parameters$mu<-list(equations=c(1,1),
 			depVar=TRUE,
 			expVar=FALSE,
 			specialFunction="cbind",
-			varInSpecialFunction=c(1,Inf)
+			varInSpecialFunction=c(2,Inf)
 		)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
