@@ -1,8 +1,10 @@
-describe.netcloglog<-function(){
+describe.cloglog.net<-function(){
 category <- "dichotomous"
 description  <- "Social Network Complementary Log Log Regression for Dichotomous Dependent Variables"
-package <-list(	name 	="stats",
-		version	="0.1"
+authors <- c("Skyler J. Cranmer")
+year <- 2007
+package <-list(	name 	="sna",
+		version	="1.4"
 		)
 parameters<-list(pi="pi")
 parameters$pi<-list(equations=c(1,1),
@@ -11,5 +13,5 @@ parameters$pi<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
