@@ -1,6 +1,8 @@
 describe.poisson.bayes<-function(){
-category <- "event.count"
-description  <- "Ordinal Probit Regression for Ordered Categorical Dependent Variables"
+category <- "count"
+description  <- "Bayesian Poisson Regression"
+authors <- c("Ben Goodrich", "Ying Lu")
+year <- 2007
 package <-list(	name 	="MCMCpack",
 		version	="0.6"
 		)
@@ -11,5 +13,5 @@ parameters$lambda<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
