@@ -9,7 +9,7 @@ netbinom <- function (formula, data, LF="logit", family=binomial(link=LF), ...,
         for (i in 2:length(glist)) x <- cbind(x, gvectorize(glist[[i]], 
             mode = mode, diag = diag, censor.as.na = TRUE))
         if (!is.matrix(x)) 
-            x <- matrix(x, nc = 1)
+            x <- matrix(x, ncol = 1)
         mis <- is.na(y) | apply(is.na(x), 1, any)
         glm.fit(x[!mis, ], y[!mis], family = binomial(link=LF), intercept = FALSE)
     }
@@ -20,7 +20,7 @@ netbinom <- function (formula, data, LF="logit", family=binomial(link=LF), ...,
         for (i in 2:length(glist)) x <- cbind(x, gvectorize(glist[[i]], 
             mode = mode, diag = diag, censor.as.na = TRUE))
         if (!is.matrix(x)) 
-            x <- matrix(x, nc = 1)
+            x <- matrix(x, ncol = 1)
         mis <- is.na(y) | apply(is.na(x), 1, any)
         list(qr(x[!mis, ], tol = tol), y[!mis])
     }
@@ -128,7 +128,7 @@ netbinom <- function (formula, data, LF="logit", family=binomial(link=LF), ...,
                 gr[[i + 1]] <- switch(nullhyp, cugtie <- rgraph(n, 
                   mode = mode, diag = diag, replace = FALSE, 
                   tielist = g[[i + 1]]), cugden <- rgraph(n, 
-                  tp = gden(g[[i + 1]], mode = mode, diag = diag), 
+                  tprob = gden(g[[i + 1]], mode = mode, diag = diag), 
                   mode = mode, diag = diag), cuguman <- (function(dc, 
                   n) {
                   rguman(1, n, mut = x[1], asym = x[2], null = x[3], 
