@@ -1,6 +1,6 @@
 param.rq <- function(object, num, bootstrap=FALSE){
     if (!bootstrap){
-        rq.sum <- summary.rq(object, cov=TRUE, se=object$se)
+        rq.sum <- summary.rq(object, covariance=TRUE, se=object$se)
         coef <- mvrnorm(num, mu=object$coef, Sigma=rq.sum$cov)
     }
 
