@@ -7,7 +7,7 @@ addVigs2WinMenu <- function(pkgName) {
        if (!file.exists(vigFile)) {
            warning(sprintf("%s contains no vignette, nothing is added to the menu bar", pkgName))
        } else {
-           vigMtrx <- .readRDS(vigFile)
+           vigMtrx <- readRDS(vigFile)
            vigs <- file.path(.find.package(pkgName), "doc", vigMtrx[,"PDF"])
            names(vigs) <- vigMtrx[,"Title"]
 
